class JobDisplay extends RessourceDisplay {
  constructor(displayElement) {
    super(displayElement);
    this.job = undefined;
    this.user.eventListeners.job.addEventListener((eventType, payload) => this.eventHandler(eventType, payload), displayElement.dataset.jobId);
  }

  init(job) {
    this.job = job;
    this.setCreationDate(this.job.creation_date);
    this.setEndDate(this.job.creation_date);
    this.setDescription(this.job.description);
    this.setService(this.job.service);
    this.setServiceArgs(this.job.service_args);
    this.setServiceVersion(this.job.service_version);
    this.setStatus(this.job.status);
    this.setTitle(this.job.title);
  }

  patch(patch) {
    let re;
    for (let operation of patch) {
      switch(operation.op) {
        case 'replace':
          // Matches: /jobs/{this.job.id}/status
          re = new RegExp('^/jobs/' + this.job.id + '/end_date');
          if (re.test(operation.path)) {this.setEndDate(operation.value); break;}
          // Matches: /jobs/{this.job.id}/status
          re = new RegExp('^/jobs/' + this.job.id + '/status$');
          if (re.test(operation.path)) {this.setStatus(operation.value); break;}
          break;
        default:
          break;
      }
    }
  }

  setTitle(title) {
    for (let element of this.displayElement.querySelectorAll('.job-title')) {this.setElement(element, title);}
  }

  setDescription(description) {
    for (let element of this.displayElement.querySelectorAll('.job-description')) {this.setElement(element, description);}
  }

  setStatus(status) {
    for (let element of this.displayElement.querySelectorAll('.job-status')) {
      this.setElement(element, status);
    }
    for (let element of this.displayElement.querySelectorAll('.status')) {element.dataset.status = status;}
    for (let element of this.displayElement.querySelectorAll('.status-spinner')) {
      if (['complete', 'failed'].includes(status)) {
        element.classList.add('hide');
      } else {
        element.classList.remove('hide');
      }
    }
    for (let element of this.displayElement.querySelectorAll('.restart-job-trigger')) {
      if (['complete', 'failed'].includes(status)) {
        element.classList.remove('hide');
      } else {
        element.classList.add('hide');
      }
    }
  }

  setCreationDate(creationDateTimestamp) {
    let creationDate = new Date(creationDateTimestamp * 1000).toLocaleString("en-US");
    for (let element of this.displayElement.querySelectorAll('.job-creation-date')) {this.setElement(element, creationDate);}
  }

  setEndDate(endDateTimestamp) {
    let endDate = new Date(endDateTimestamp * 1000).toLocaleString("en-US");
    for (let element of this.displayElement.querySelectorAll('.job-end-date')) {this.setElement(element, endDate);}
  }

  setService(service) {
    for (let element of this.displayElement.querySelectorAll('.job-service')) {this.setElement(element, service);}
  }

  setServiceArgs(serviceArgs) {
    for (let element of this.displayElement.querySelectorAll('.job-service-args')) {this.setElement(element, serviceArgs);}
  }

  setServiceVersion(serviceVersion) {
    for (let element of this.displayElement.querySelectorAll('.job-service-version')) {this.setElement(element, serviceVersion);}
  }
}
